# Filtering in Custom Reports
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/filtering-in-custom-reports#overview)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/filtering-in-custom-reports#prerequisites)
  * [Step 1: Navigate to the Project Directory](https://help.sap.com/docs/leanix/ea/filtering-in-custom-reports#step-1:-navigate-to-the-project-directory)
  * [Step 2: Create a Custom Report Module](https://help.sap.com/docs/leanix/ea/filtering-in-custom-reports#step-2:-create-a-custom-report-module)
  * [Step 3: Import Facets into the Main Module](https://help.sap.com/docs/leanix/ea/filtering-in-custom-reports#step-3:-import-facets-into-the-main-module)
  * [Step 4: Start the Development Server](https://help.sap.com/docs/leanix/ea/filtering-in-custom-reports#step-4:-start-the-development-server)
  * [Step 5: Use Filters in the Filter Sidebar](https://help.sap.com/docs/leanix/ea/filtering-in-custom-reports#step-5:-use-filters-in-the-filter-sidebar)
  * [Summary](https://help.sap.com/docs/leanix/ea/filtering-in-custom-reports#summary)


Learn how to use facets to filter data when building custom reports.
